@@ -3,20 +3,17 @@ use strict;
 use warnings;
 
 package Git::Wrapper;
-{
-  $Git::Wrapper::VERSION = '0.028_97';
-}
 #ABSTRACT: Wrap git(7) command-line interface
+$Git::Wrapper::VERSION = '0.045_090'; # TRIAL
 
-our $DEBUG=0;
+$Git::Wrapper::VERSION = '0.045090';our $DEBUG=0;
 
 # Prevent ANSI color with extreme prejudice
 # https://github.com/genehack/Git-Wrapper/issues/13
 delete $ENV{GIT_PAGER_IN_USE};
 
-use File::pushd;
+use File::chdir;
 use File::Temp;
-use IPC::Cmd        qw(can_run);
 use IPC::Open3      qw();
 use Scalar::Util    qw(blessed);
 use Sort::Versions;
@@ -87,7 +84,7 @@ sub RUN {
   my( @out , @err );
 
   {
-    my $d = pushd $self->dir unless $cmd eq 'clone';
+    local $CWD = $self->dir unless $cmd eq 'clone';
 
     my ($wtr, $rdr, $err);
 
@@ -107,7 +104,7 @@ sub RUN {
     print STDERR join(' ',@cmd),"\n" if $DEBUG;
 
     # Prevent commands from running interactively
-    local $ENV{GIT_EDITOR} = '';
+    local $ENV{GIT_EDITOR} = ' ';
 
     my $pid = IPC::Open3::open3($wtr, $rdr, $err, @cmd);
     print $wtr $stdin
@@ -164,17 +161,31 @@ sub git {
   return ( defined $ENV{GIT_WRAPPER_GIT} ) ? $ENV{GIT_WRAPPER_GIT} : 'git';
 }
 
-sub has_git_in_path { can_run('git') }
+sub has_git_in_path {
+  require IPC::Cmd;
+  IPC::Cmd::can_run('git');
+}
 
 sub log {
   my $self = shift;
 
+  if ( grep /format=/, @_ ) {
+    die Git::Wrapper::Exception->new(
+      error  => [qw/--format not allowed. Use the RUN() method if you with to use a custom log format./],
+      output => undef,
+      status => 255 ,
+    );
+  }
+
   my $opt  = ref $_[0] eq 'HASH' ? shift : {};
   $opt->{no_color}         = 1;
   $opt->{pretty}           = 'medium';
+  $opt->{no_abbrev}        = 1;  # https://github.com/genehack/Git-Wrapper/issues/67
 
   $opt->{no_abbrev_commit} = 1
     if $self->supports_log_no_abbrev_commit;
+  $opt->{no_expand_tabs} = 1
+    if $self->supports_log_no_expand_tabs;
 
   my $raw = defined $opt->{raw} && $opt->{raw};
 
@@ -212,7 +223,9 @@ sub log {
     if ($raw) {
       my @modifications;
 
-      while(@out and $out[0] =~ m/^\:(\d{6}) (\d{6}) (\w{7})\.\.\. (\w{7})\.\.\. (\w{1})\t(.*)$/) {
+      # example output:
+      # :000000 100644 0000000000000000000000000000000000000000 ce013625030ba8dba906f756967f9e9ca394464a A     foo/bar
+      while(@out and $out[0] =~ m/^\:(\d{6}) (\d{6}) (\w{40}) (\w{40}) (\w{1})\t(.*)$/) {
         push @modifications, Git::Wrapper::File::RawModification->new($6,$5,$1,$2,$3,$4);
         shift @out;
       }
@@ -220,6 +233,9 @@ sub log {
     }
 
     push @logs, $current;
+
+    last unless @out; # handle running out of log
+    shift @out unless $out[0] =~ /^commit/;  # blank line at end of entry, except merge commits;
   }
 
   return @logs;
@@ -276,6 +292,14 @@ sub supports_log_no_abbrev_commit {
   return ( versioncmp( $self->version , '1.7.6' ) eq -1 ) ? 0 : 1;
 }
 
+sub supports_log_no_expand_tabs {
+  my $self = shift;
+
+  # The '--no-expand-tabs' option to git log was added in version 2.9.0
+  return 0 if ( versioncmp( $self->version , '2.9' ) eq -1 );
+  return 1;
+}
+
 sub supports_log_raw_dates {
   my $self = shift;
 
@@ -311,21 +335,19 @@ sub _message_tempfile {
   return ( "file", '"'.$tmp->filename.'"' );
 }
 
-sub _munge_val {
+sub _opt_and_val {
   my( $name , $val ) = @_;
 
-  return $val eq '1'       ? ""
-    : length($name) == 1 ? $val
-      :                      "=$val";
-}
-
-sub _opt {
-  my $name = shift;
   $name =~ tr/_/-/;
-  return length($name) == 1
+  my $opt = length($name) == 1
     ? "-$name"
       : "--$name"
         ;
+
+  return
+      $val eq '1' ? ($opt)
+    : length($name) == 1 ? ($opt, $val)
+    :                      "$opt=$val";
 }
 
 sub _parse_args {
@@ -340,18 +362,18 @@ sub _parse_args {
       $stdin = delete $_->{-STDIN}
         if exists $_->{-STDIN};
 
-      for my $name ( keys %$_ ) {
+      for my $name ( sort keys %$_ ) {
         my $val = delete $_->{$name};
         next if $val eq '0';
 
         if ( $name =~ s/^-// ) {
-          push @pre_cmd , _opt( $name ) . _munge_val( $name , $val );
+          push @pre_cmd , _opt_and_val( $name , $val );
         }
         else {
           ( $name, $val ) = _message_tempfile( $val )
             if _win32_multiline_commit_msg( $cmd, $name, $val );
 
-          push @post_cmd , _opt( $name ) . _munge_val( $name , $val );
+          push @post_cmd , _opt_and_val( $name , $val );
         }
       }
     }
@@ -383,13 +405,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Git::Wrapper - Wrap git(7) command-line interface
 
 =head1 VERSION
 
-version 0.028_97
+version 0.045_090
 
 =head1 SYNOPSIS
 
@@ -413,14 +437,14 @@ argument passing, instead of CLI-style C<--options> as L<Git> does.
 
 Except as documented, every git subcommand is available as a method on a
 Git::Wrapper object. Replace any hyphens in the git command with underscores
-(for example, 'git init-db' would become C<$git->init_db>).
+(for example, C<git init-db> would become C<< $git->init_db >>).
 
 =head2 Method Arguments
 
 Methods accept a combination of hashrefs and scalars, which is used to build
 the command used to invoke git. Arguments passed in hashrefs will be
 automatically parsed into option pairs, but the ordering of these in the
-resulting shell command is not guarenteed (with the exceptino of options with
+resulting shell command is not guaranteed (with the exception of options with
 a leading '-'; see below). Options that are passed as plain scalars will
 retain their order. Some examples may help clarify. This code:
 
@@ -457,7 +481,7 @@ invokes the command line
 
 I<N.b.> Because of the way arguments are parsed, should you need to pass an
 explicit '0' value to an option (for example, to have the same effect as
-C<--abrrev=0> on the command line), you should pass it with a leading space, like so:
+C<--abbrev=0> on the command line), you should pass it with a leading space, like so:
 
   $git->describe({ abbrev => ' 0' };
 
@@ -481,25 +505,85 @@ yourself before passing it to C<Git::Wrapper> methods.
 =head2 Error handling
 
 If a git command exits nonzero, a C<Git::Wrapper::Exception> object will be
-thrown (via C<die()>). These objects have three useful methods:
+thrown (via C<die>) and may be capture via C<eval> or L<Try::Tiny>, for
+example.
+
+The error object has three useful methods:
 
 =over
 
 =item * error
 
-error message
+Returns the full error message reported by the resulting git command sent to
+C<STDERR>. This method should not be used as a success/failure check, as
+C<git> will sometimes produce output on STDERR when a command is successful.
 
 =item * output
 
-normal output, as a single string
+Returns the full output generated by the git command that is sent to
+C<STDOUT>.  This method should not be used as a success/failure check, as
+C<git> will frequently not have any output with a successful command.
 
 =item * status
 
-the exit status
+Returns the non-zero exit code reported by git on error
 
 =back
 
-These exception objects stringify to the error message.
+=head3 Using Try::Tiny
+
+L<Try::Tiny> is the recommended way to catch exception objects thrown by
+L<Git::Wrapper>.
+
+  use Try::Tiny
+
+  my $git = Git::Wrapper->new('/path/to/my/repo');
+
+  try {
+    # equivalent to, "git --non-existent-option=1" on the commandline
+    $git->status({ "non-existent-option"=>1 });
+  }
+  catch {
+    # print STERR from erroneous git command
+    print $_->error;
+
+    # print STOUT from git command
+    print $_->output;
+
+    # print non-zero exist status of git processo
+    print $_->status;
+
+    # quotes are overloaded, so:
+    print "$_"; # equivalent to $_->error
+  };
+
+=head3 Using C<eval>
+
+If for some reason you are unable to use L<Try::Tiny>, it is also possible to
+use the C<eval> function to catch exception objects. B<THIS IS NOT
+RECOMMENDED!>
+
+  my $git = Git::Wrapper->new('/path/to/my/repo');
+
+  my $ok = eval {
+    # equivalent to, "git --non-existent-option=1" on the commandline
+    $git->status({ "non-existent-option"=>1 });
+    1;
+  };
+
+  if ($@ and ref $@ eq q{Git::Wrapper::Exception}) {
+    # print STERR from erroneous git command
+    print $@->error;
+
+    # print STOUT from git command
+    print $@->output;
+
+    # print non-zero exist status of git processo
+    print $@->status;
+
+    # quotes are overloaded, so:
+    print "$@"; # equivalent to $@->error
+  }
 
 =head1 METHODS
 
@@ -536,7 +620,9 @@ you want ANSI color highlighting, you'll need to bypass via the RUN() method
   my @logs = $git->log;
 
 Instead of giving back an arrayref of lines, the C<log> method returns a list
-of C<Git::Wrapper::Log> objects. They have four methods:
+of C<Git::Wrapper::Log> objects.
+
+There are five methods in a C<Git::Wrapper::Log> objects:
 
 =over
 
@@ -548,8 +634,46 @@ of C<Git::Wrapper::Log> objects. They have four methods:
 
 =item * message
 
+=item * modifications
+
+Only populated with when C<< raw => 1 >> option is set; see L<Raw logs> below.
+
 =back
 
+=head3 Raw logs
+
+Calling the C<log> method with the C<< raw => 1 >> option set, as below, will
+do additional parsing to populate the C<modifications> attribute on each
+C<Git::Wrapper::Log> object. This method returns a list of
+C<Git::Wrapper::File::RawModification> objects, with can be used to get
+filenames, permissions, and other metadata associated with individual files in
+the given commit. A short example, to loop over all commits in the log and
+print the filenames that were changed in each commit, one filename per file:
+
+    my @logs = $git->log({ raw => 1 });
+    foreach my $log ( @logs ) {
+        say "In commit '" . $log->id . "', the following files changed:";
+        my @mods = $log->modifications;
+        foreach my $mod ( @mods ) {
+            say "\t" . $mod->filename;
+        }
+    }
+
+Note that some commits (e.g., merge commits) will not contain any file
+changes. The C<modifications> method will return an empty list in that case.
+
+=head3 Custom log formats
+
+C<log> will throw an exception if it is passed the C<--format> option. The
+reason for this has to do with the fact that the parsing of the full log
+output into C<Git::Wrapper::Log> objects assumes the default format provided
+by `git` itself. Passing C<--format> to the underlying `git log` method affects
+this assumption and the output is no longer able to be processed as intented.
+
+If you wish to specify a custom log format, please use the L<RUN> method
+directly.  The caller will be supplied with the full log output. From there,
+the caller may process the output as it wishes.
+
 =head2 has_git_in_path
 
 This method returns a true or false value indicating if there is a 'git'
@@ -559,14 +683,17 @@ binary in the current $PATH.
 
 =head2 supports_log_no_abbrev_commit
 
+=head2 supports_log_no_expand_tabs
+
 =head2 supports_log_raw_dates
 
 =head2 supports_hash_object_filters
 
 These methods return a true or false value (1 or 0) indicating whether the git
 binary being used has support for these options. (The '--porcelain' option on
-'git status', the '--no-abbrev-commit' and '--date=raw' options on 'git log',
-and the '--no-filters' option on 'git hash-object' respectively.)
+'git status', the '--no-abbrev-commit', '--no-expand-tabs', and '--date=raw'
+options on 'git log', and the '--no-filters' option on 'git hash-object'
+respectively.)
 
 These are primarily for use in this distribution's test suite, but may also be
 useful when writing code using Git::Wrapper that might be run with different
@@ -700,7 +827,7 @@ methods described above (i.e., C<log>, C<status>, etc.). This can be useful
 in various situations, such as when you want to produce a particular log
 output format that isn't compatible with the way C<Git::Wrapper> constructs
 C<Git::Wrapper::Log>, or when you want raw C<git status> output that isn't
-parsed into a <Git::Wrapper::Status> object.
+parsed into a C<Git::Wrapper::Status> object.
 
 This method should be called with an initial string argument of the C<git>
 subcommand you want to run, followed by a hashref containing options and their
@@ -716,6 +843,9 @@ values, and then a list of any other arguments.
     # while 'RUN('log')' returns an array of chomped lines
     my @log_lines = $git->RUN('log');
 
+    # getting the full of commit SHAs via `git log` by using the '--format' option
+    my @log_lines = $git->RUN('log', '--format=%H');
+
 =head2 ERR
 
 After a command has been run, this method will return anything that was sent
@@ -752,7 +882,7 @@ instead pass the binary location (git_binary) to new on object creation.
 =head1 SEE ALSO
 
 L<VCI::VCS::Git> is the git implementation for L<VCI>, a generic interface to
-version-controle systems.
+version-control systems.
 
 L<Other Perl Git Wrappers|https://metacpan.org/module/Git::Repository#OTHER-PERL-GIT-WRAPPERS>
 is a list of other Git interfaces in Perl. If L<Git::Wrapper> doesn't scratch
@@ -789,7 +919,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Hans Dieter Pearcey.
+This software is copyright (c) 2014 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
