@@ -1,10 +1,8 @@
 package Git::Wrapper::File::RawModification;
-{
-  $Git::Wrapper::File::RawModification::VERSION = '0.028_97';
-}
 # ABSTRACT: Modification of a file in a commit
+$Git::Wrapper::File::RawModification::VERSION = '0.045_090'; # TRIAL
 
-use 5.006;
+$Git::Wrapper::File::RawModification::VERSION = '0.045090';use 5.006;
 use strict;
 use warnings;
 
@@ -35,13 +33,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Git::Wrapper::File::RawModification - Modification of a file in a commit
 
 =head1 VERSION
 
-version 0.028_97
+version 0.045_090
 
 =head1 METHODS
 
@@ -94,7 +94,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Hans Dieter Pearcey.
+This software is copyright (c) 2014 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
