@@ -1,20 +1,18 @@
 package Git::Wrapper::Log;
-{
-  $Git::Wrapper::Log::VERSION = '0.028_97';
-}
 # ABSTRACT: Log line of the Git
+$Git::Wrapper::Log::VERSION = '0.045_090'; # TRIAL
 
-use 5.006;
+$Git::Wrapper::Log::VERSION = '0.045090';use 5.006;
 use strict;
 use warnings;
 
 sub new {
   my ($class, $id, %arg) = @_;
-  my $modifications = defined $arg{modifications} ? $arg{modifications} : [];
+  my $modifications = defined $arg{modifications} ? delete $arg{modifications} : [];
   return bless {
     id            => $id,
     attr          => {},
-    modifications => [],
+    modifications => $modifications,
     %arg,
   } => $class;
 }
@@ -43,13 +41,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Git::Wrapper::Log - Log line of the Git
 
 =head1 VERSION
 
-version 0.028_97
+version 0.045_090
 
 =head1 METHODS
 
@@ -100,7 +100,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Hans Dieter Pearcey.
+This software is copyright (c) 2014 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
