@@ -3,12 +3,10 @@ use strict;
 use warnings;
 
 package Git::Wrapper::Status;
-{
-  $Git::Wrapper::Status::VERSION = '0.028_97';
-}
 # ABSTRACT: A specific status information in the Git
+$Git::Wrapper::Status::VERSION = '0.045_090'; # TRIAL
 
-my %modes = (
+$Git::Wrapper::Status::VERSION = '0.045090';my %modes = (
   M   => 'modified',
   A   => 'added',
   D   => 'deleted',
@@ -47,13 +45,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Git::Wrapper::Status - A specific status information in the Git
 
 =head1 VERSION
 
-version 0.028_97
+version 0.045_090
 
 =head1 METHODS
 
@@ -100,7 +100,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Hans Dieter Pearcey.
+This software is copyright (c) 2014 by Hans Dieter Pearcey.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
